@@ -1,6 +1,7 @@
 package js
 
 import (
+	"bytes"
 	"io"
 	"testing"
 
@@ -196,10 +197,15 @@ func TestJS(t *testing.T) {
 		{"(x) => { y(); };", "(x) => { y(); }; "},
 		{"(x, y) => { z(); };", "(x, y) => { z(); }; "},
 		{"async (x, y) => { z(); };", "async (x, y) => { z(); }; "},
+
+		// Await keyword
+		{"await x;", "await x; "},
+		{"export default await x;", "export default await x; "},
+		{"export let a = await x;", "export let a = await x; "},
 	}
 	for _, tt := range tests {
 		t.Run(tt.js, func(t *testing.T) {
-			ast, err := Parse(parse.NewInputString(tt.js))
+			ast, err := Parse(parse.NewInputString(tt.js), Options{})
 			if err != io.EOF {
 				test.Error(t, err)
 			}
@@ -213,14 +219,30 @@ func TestJSRealWorldJS(t *testing.T) {
 	var _0x34d2=['log','415343ArZKCi','11ItVJMI','98599KfnlVw','139pQCPDx','526583DuLSJk','Hello\x20World!','5823JSTLxZ','543807ONUblA','2uewDkG','146389ygBdVV','2273BZpJsB'];(function(_0x6b2cbe,_0x3fd0f4){var _0xffa95b=_0x3d17;while(!![]){try{var _0x5239dc=-parseInt(_0xffa95b(0x132))+parseInt(_0xffa95b(0x12f))+-parseInt(_0xffa95b(0x131))*-parseInt(_0xffa95b(0x12c))+parseInt(_0xffa95b(0x135))*-parseInt(_0xffa95b(0x12e))+-parseInt(_0xffa95b(0x12d))+-parseInt(_0xffa95b(0x134))+-parseInt(_0xffa95b(0x133))*-parseInt(_0xffa95b(0x12b));if(_0x5239dc===_0x3fd0f4)break;else _0x6b2cbe['push'](_0x6b2cbe['shift']());}catch(_0x12a1ea){_0x6b2cbe['push'](_0x6b2cbe['shift']());}}}(_0x34d2,0x4d4a4));function hi(){var _0x2d5dfd=_0x3d17;console[_0x2d5dfd(0x12a)](_0x2d5dfd(0x130));}function _0x3d17(_0x59c992,_0x5be83e){_0x59c992=_0x59c992-0x12a;var _0x34d208=_0x34d2[_0x59c992];return _0x34d208;}hi();
 	`
 
-	ast, err := Parse(parse.NewInputString(js))
+	ast, err := Parse(parse.NewInputString(js), Options{})
 	if err != nil && err != io.EOF {
 		t.Fatal(err)
 	}
 
 	// reparse to make sure JS is still valid
-	_, err = Parse(parse.NewInputString(ast.JS()))
+	_, err = Parse(parse.NewInputString(ast.JS()), Options{})
 	if err != nil {
 		t.Error("Err: ", err)
 	}
 }
+
+func TestJSON(t *testing.T) {
+	json := `x=[{"key": [2.5, '\r'], '"': -2E+9}, null, false, true, 5.0e-6, "string", 'stri"ng']`
+
+	ast, err := Parse(parse.NewInputString(json), Options{})
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	val := ast.List[0].(*ExprStmt).Value.(*BinaryExpr).Y.(JSONer)
+	buf := &bytes.Buffer{}
+	if err := val.JSON(buf); err != nil {
+		t.Fatal(err)
+	}
+	test.String(t, buf.String(), `[{"key": [2.5, "\r"], "\"": -2E+9}, null, false, true, 5.0e-6, "string", "stri\"ng"]`)
+}
